@@ -17,6 +17,8 @@ from sklearn.metrics import f1_score
 #import general as g
 #import core_helper.model.general as g
 #import src.Prj_Core.core_helper.model.general as g
+
+
 from data_science_helper.model import general as g
 
 import time
@@ -157,16 +159,18 @@ def get_default_params_old():
     return params
 
 
-def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric=None,num_rounds=None,early_stop=None,log=None,random_state=42,api="train_api",strategy="",url=None):
-    start = time.time()
+def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric=None,num_rounds=None,early_stop=None,log=None,random_state=42,api="train_api",strategy=None, url=None):
+    
     model = None
     
-    print("strategy: ",strategy)
-    if (strategy=="neg_bagging_fraction__lgb_model"):
-        params = get_neg_bagging_fraction_params(y_train,params)
-        
-    if (strategy=="scale_pos_weight__lgb_model"):
-        params = get_scale_pos_weight_params(y_train,params)
+    if strategy is not None:
+    
+        print("strategy: ",strategy)
+        if (strategy=="neg_bagging_fraction__lgb_model"):
+            params = get_neg_bagging_fraction_params(y_train,params)
+            
+        if (strategy=="scale_pos_weight__lgb_model"):
+            params = get_scale_pos_weight_params(y_train,params)
 
     
     if api=="train_api":
